package com.iotechn.unimall.admin.api.card;


import com.iotechn.unimall.core.annotation.HttpMethod;
import com.iotechn.unimall.core.annotation.HttpOpenApi;
import com.iotechn.unimall.core.annotation.HttpParam;
import com.iotechn.unimall.core.annotation.HttpParamType;
import com.iotechn.unimall.core.annotation.param.NotNull;
import com.iotechn.unimall.core.exception.ServiceException;
import com.iotechn.unimall.data.domain.CardExchangeInfo;
import com.iotechn.unimall.data.model.Page;
import java.util.Date;

/**
 * 名片交换Service接口
 * 
 * @author jlb
 * @date 2023-04-12
 */
@HttpOpenApi(group = "admin.unimall.cardExchangeInfo", description = "名片交换")
public interface ICardExchangeInfoService{
	@HttpMethod(description = "新增", permissionName = "名片交换管理")
	public Boolean add(@NotNull @HttpParam(name = "cardExchangeInfo", type = HttpParamType.COMMON, description = "名片交换") CardExchangeInfo cardExchangeInfo)throws ServiceException;

	@HttpMethod(description = "列表", permissionName = "名片交换管理")
	public Page<CardExchangeInfo> list(
								@HttpParam(name = "sendId", type = HttpParamType.COMMON, description = "发起人id") Long sendId,
							@HttpParam(name = "receiveId", type = HttpParamType.COMMON, description = "接收人id") Long receiveId,
							@HttpParam(name = "sendCardId", type = HttpParamType.COMMON, description = "发起人名片id") Long sendCardId,
							@HttpParam(name = "receiveCardId", type = HttpParamType.COMMON, description = "接收人名片id") Long receiveCardId,
							@HttpParam(name = "circleName", type = HttpParamType.COMMON, description = "圈子名称") String circleName,
							@HttpParam(name = "status", type = HttpParamType.COMMON, description = "状态(1已接受3已拒绝5已过期)") String status,
							@HttpParam(name = "gmtCreate", type = HttpParamType.COMMON, description = "") Date gmtCreate,
							@HttpParam(name = "gmtUpdate", type = HttpParamType.COMMON, description = "") Date gmtUpdate,
							@HttpParam(name = "deleteFlag", type = HttpParamType.COMMON, description = "删除标识") Long deleteFlag,
					@HttpParam(name = "page", type = HttpParamType.COMMON, description = "页码", valueDef = "1") Integer page,
		@HttpParam(name = "limit", type = HttpParamType.COMMON, description = "页码长度", valueDef = "20") Integer limit)
		throws ServiceException;

	@HttpMethod(description = "删除", permissionName = "名片交换管理")
	public Boolean delete(@NotNull @HttpParam(name = "id", type = HttpParamType.COMMON, description = "")String id)throws ServiceException;

	@HttpMethod(description = "修改", permissionName = "名片交换管理")
	public Boolean update(@NotNull @HttpParam(name = "cardExchangeInfo", type = HttpParamType.COMMON, description = "名片交换") CardExchangeInfo cardExchangeInfo,
						  @HttpParam(name = "updateFlag", type = HttpParamType.COMMON, description = "updateFlag") String updateFlag)throws ServiceException;

	@HttpMethod(description = "查询", permissionName = "名片交换管理")
	public CardExchangeInfo get(@NotNull @HttpParam(name = "id", type = HttpParamType.COMMON, description = "")Long id)throws ServiceException;
	
	@HttpMethod(description = "导出excl表", permissionName = "名片交换管理")
	public String export(
								@HttpParam(name = "sendId", type = HttpParamType.COMMON, description = "发起人id") Long sendId,
							@HttpParam(name = "receiveId", type = HttpParamType.COMMON, description = "接收人id") Long receiveId,
							@HttpParam(name = "sendCardId", type = HttpParamType.COMMON, description = "发起人名片id") Long sendCardId,
							@HttpParam(name = "receiveCardId", type = HttpParamType.COMMON, description = "接收人名片id") Long receiveCardId,
							@HttpParam(name = "circleName", type = HttpParamType.COMMON, description = "圈子名称") String circleName,
							@HttpParam(name = "status", type = HttpParamType.COMMON, description = "状态(1已接受3已拒绝5已过期)") String status,
							@HttpParam(name = "gmtCreate", type = HttpParamType.COMMON, description = "") Date gmtCreate,
							@HttpParam(name = "gmtUpdate", type = HttpParamType.COMMON, description = "") Date gmtUpdate,
							@HttpParam(name = "deleteFlag", type = HttpParamType.COMMON, description = "删除标识") Long deleteFlag,
				@HttpParam(name = "page", type = HttpParamType.COMMON, description = "页码", valueDef = "1") Integer page,
	@HttpParam(name = "limit", type = HttpParamType.COMMON, description = "页码长度", valueDef = "20") Integer limit)throws ServiceException;
	
}
