package com.iotechn.unimall.admin.api.market;


import com.iotechn.unimall.data.domain.market.MarketAdvertisementInfo;
import com.iotechn.unimall.core.annotation.HttpMethod;
import com.iotechn.unimall.core.annotation.HttpOpenApi;
import com.iotechn.unimall.core.annotation.HttpParam;
import com.iotechn.unimall.core.annotation.HttpParamType;
import com.iotechn.unimall.core.annotation.param.NotNull;
import com.iotechn.unimall.core.exception.ServiceException;
import com.iotechn.unimall.data.model.Page;

import java.util.Date;

/**
 * 广告信息Service接口
 *
 * @author jlb
 * @date 2022-08-01
 */
@HttpOpenApi(group = "admin.market.marketAdvertisementInfo", description = "广告信息")
public interface IMarketAdvertisementInfoService {
    @HttpMethod(description = "新增", permission = "admin:market:marketAdvertisementInfo:add", permissionParentName = "宠物管理", permissionName = "广告信息管理")
    public Boolean add(@NotNull @HttpParam(name = "marketAdvertisementInfo", type = HttpParamType.COMMON, description = "广告信息") MarketAdvertisementInfo marketAdvertisementInfo,
                       @HttpParam(name = "adminId", type = HttpParamType.ADMIN_ID, description = "adminId") Long adminId) throws ServiceException;

    @HttpMethod(description = "列表", permission = "admin:market:marketAdvertisementInfo:list", permissionParentName = "宠物管理", permissionName = "广告信息管理")
    public Page<MarketAdvertisementInfo> list(
            @HttpParam(name = "companyId", type = HttpParamType.COMMON, description = "") Long companyId,
            @HttpParam(name = "advertisementName", type = HttpParamType.COMMON, description = "广告名称") String advertisementName,
            @HttpParam(name = "url", type = HttpParamType.COMMON, description = "图片") String url,
            @HttpParam(name = "status", type = HttpParamType.COMMON, description = "状态") String status,
            @HttpParam(name = "deleteFlag", type = HttpParamType.COMMON, description = "0：否（默认） 1：是") Integer deleteFlag,
            @HttpParam(name = "gmtCreate", type = HttpParamType.COMMON, description = "") Date gmtCreate,
            @HttpParam(name = "gmtUpdate", type = HttpParamType.COMMON, description = "") Date gmtUpdate,
            @HttpParam(name = "userId", type = HttpParamType.COMMON, description = "") Long userId,
            @HttpParam(name = "adminId", type = HttpParamType.COMMON, description = "") Long adminId,
            @HttpParam(name = "page", type = HttpParamType.COMMON, description = "页码", valueDef = "1") Integer page,
            @HttpParam(name = "limit", type = HttpParamType.COMMON, description = "页码长度", valueDef = "20") Integer limit)
            throws ServiceException;

    @HttpMethod(description = "删除", permission = "admin:market:marketAdvertisementInfo:delete", permissionParentName = "宠物管理", permissionName = "广告信息管理")
    public Boolean delete(@NotNull @HttpParam(name = "id", type = HttpParamType.COMMON, description = "") String id) throws ServiceException;

    @HttpMethod(description = "修改", permission = "admin:market:marketAdvertisementInfo:update", permissionParentName = "宠物管理", permissionName = "广告信息管理")
    public Boolean update(@NotNull @HttpParam(name = "marketAdvertisementInfo", type = HttpParamType.COMMON, description = "广告信息") MarketAdvertisementInfo marketAdvertisementInfo,
                          @HttpParam(name = "adminId", type = HttpParamType.ADMIN_ID, description = "adminId") Long adminId) throws ServiceException;

    @HttpMethod(description = "查询", permission = "admin:market:marketAdvertisementInfo:get", permissionParentName = "宠物管理", permissionName = "广告信息管理")
    public MarketAdvertisementInfo get(@NotNull @HttpParam(name = "id", type = HttpParamType.COMMON, description = "") Long id) throws ServiceException;

    @HttpMethod(description = "导出excl表", permission = "admin:market:marketAdvertisementInfo:export", permissionParentName = "宠物管理", permissionName = "广告信息管理")
    public String export(
            @HttpParam(name = "companyId", type = HttpParamType.COMMON, description = "") Long companyId,
            @HttpParam(name = "advertisementName", type = HttpParamType.COMMON, description = "广告名称") String advertisementName,
            @HttpParam(name = "url", type = HttpParamType.COMMON, description = "图片") String url,
            @HttpParam(name = "status", type = HttpParamType.COMMON, description = "状态") String status,
            @HttpParam(name = "deleteFlag", type = HttpParamType.COMMON, description = "0：否（默认） 1：是") Integer deleteFlag,
            @HttpParam(name = "gmtCreate", type = HttpParamType.COMMON, description = "") Date gmtCreate,
            @HttpParam(name = "gmtUpdate", type = HttpParamType.COMMON, description = "") Date gmtUpdate,
            @HttpParam(name = "userId", type = HttpParamType.COMMON, description = "") Long userId,
            @HttpParam(name = "adminId", type = HttpParamType.COMMON, description = "") Long adminId,
            @HttpParam(name = "page", type = HttpParamType.COMMON, description = "页码", valueDef = "1") Integer page,
            @HttpParam(name = "limit", type = HttpParamType.COMMON, description = "页码长度", valueDef = "20") Integer limit) throws ServiceException;

}
