package com.iotechn.unimall.admin.api.market;


import com.iotechn.unimall.core.annotation.HttpMethod;
import com.iotechn.unimall.core.annotation.HttpOpenApi;
import com.iotechn.unimall.core.annotation.HttpParam;
import com.iotechn.unimall.core.annotation.HttpParamType;
import com.iotechn.unimall.core.annotation.param.NotNull;
import com.iotechn.unimall.core.exception.ServiceException;
import com.iotechn.unimall.data.domain.market.MarketShopInfo;
import com.iotechn.unimall.data.model.Page;

import java.util.Date;

/**
 * 商店信息Service接口
 *
 * @author jlb
 * @date 2022-08-01
 */
@HttpOpenApi(group = "admin.unimall.marketShopInfo", description = "商店信息")
public interface IMarketShopInfoService {
    @HttpMethod(description = "新增", permission = "admin:unimall:marketShopInfo:add", permissionParentName = "宠物管理", permissionName = "商店信息管理")
    public Boolean add(@NotNull @HttpParam(name = "marketShopInfo", type = HttpParamType.COMMON, description = "商店信息") MarketShopInfo marketShopInfo,
                       @HttpParam(name = "adminId", type = HttpParamType.ADMIN_ID, description = "adminId") Long adminId) throws ServiceException;

    @HttpMethod(description = "列表", permission = "admin:unimall:marketShopInfo:list", permissionParentName = "宠物管理", permissionName = "商店信息管理")
    public Page<MarketShopInfo> list(
            @HttpParam(name = "companyId", type = HttpParamType.COMMON, description = "") Long companyId,
            @HttpParam(name = "name", type = HttpParamType.COMMON, description = "名称") String name,
            @HttpParam(name = "postion", type = HttpParamType.COMMON, description = "位置") String postion,
            @HttpParam(name = "url", type = HttpParamType.COMMON, description = "封面") String url,
            @HttpParam(name = "phone", type = HttpParamType.COMMON, description = "手机") String phone,
            @HttpParam(name = "status", type = HttpParamType.COMMON, description = "状态") String status,
            @HttpParam(name = "deleteFlag", type = HttpParamType.COMMON, description = "0：否（默认） 1：是") Integer deleteFlag,
            @HttpParam(name = "gmtCreate", type = HttpParamType.COMMON, description = "") Date gmtCreate,
            @HttpParam(name = "gmtUpdate", type = HttpParamType.COMMON, description = "") Date gmtUpdate,
            @HttpParam(name = "userId", type = HttpParamType.COMMON, description = "") Long userId,
            @HttpParam(name = "adminId", type = HttpParamType.COMMON, description = "") Long adminId,
            @HttpParam(name = "level", type = HttpParamType.COMMON, description = "信誉等级") String level,
            @HttpParam(name = "caseWorld", type = HttpParamType.COMMON, description = "关键词") String caseWorld,
            @HttpParam(name = "lon", type = HttpParamType.COMMON, description = "经度") String lon,
            @HttpParam(name = "lat", type = HttpParamType.COMMON, description = "纬度") String lat,
            @HttpParam(name = "page", type = HttpParamType.COMMON, description = "页码", valueDef = "1") Integer page,
            @HttpParam(name = "limit", type = HttpParamType.COMMON, description = "页码长度", valueDef = "20") Integer limit)
            throws ServiceException;

    @HttpMethod(description = "删除", permission = "admin:unimall:marketShopInfo:delete", permissionParentName = "宠物管理", permissionName = "商店信息管理")
    public Boolean delete(@NotNull @HttpParam(name = "id", type = HttpParamType.COMMON, description = "") String id) throws ServiceException;

    @HttpMethod(description = "修改", permission = "admin:unimall:marketShopInfo:update", permissionParentName = "宠物管理", permissionName = "商店信息管理")
    public Boolean update(@NotNull @HttpParam(name = "marketShopInfo", type = HttpParamType.COMMON, description = "商店信息") MarketShopInfo marketShopInfo,
                          @HttpParam(name = "adminId", type = HttpParamType.ADMIN_ID, description = "adminId") Long adminId) throws ServiceException;

    @HttpMethod(description = "查询", permission = "admin:unimall:marketShopInfo:get", permissionParentName = "宠物管理", permissionName = "商店信息管理")
    public MarketShopInfo get(@NotNull @HttpParam(name = "id", type = HttpParamType.COMMON, description = "") Long id) throws ServiceException;

    @HttpMethod(description = "导出excl表", permission = "admin:unimall:marketShopInfo:export", permissionParentName = "宠物管理", permissionName = "商店信息管理")
    public String export(
            @HttpParam(name = "companyId", type = HttpParamType.COMMON, description = "") Long companyId,
            @HttpParam(name = "name", type = HttpParamType.COMMON, description = "名称") String name,
            @HttpParam(name = "postion", type = HttpParamType.COMMON, description = "位置") String postion,
            @HttpParam(name = "url", type = HttpParamType.COMMON, description = "封面") String url,
            @HttpParam(name = "phone", type = HttpParamType.COMMON, description = "手机") String phone,
            @HttpParam(name = "status", type = HttpParamType.COMMON, description = "状态") String status,
            @HttpParam(name = "deleteFlag", type = HttpParamType.COMMON, description = "0：否（默认） 1：是") Integer deleteFlag,
            @HttpParam(name = "gmtCreate", type = HttpParamType.COMMON, description = "") Date gmtCreate,
            @HttpParam(name = "gmtUpdate", type = HttpParamType.COMMON, description = "") Date gmtUpdate,
            @HttpParam(name = "userId", type = HttpParamType.COMMON, description = "") Long userId,
            @HttpParam(name = "adminId", type = HttpParamType.COMMON, description = "") Long adminId,
            @HttpParam(name = "page", type = HttpParamType.COMMON, description = "页码", valueDef = "1") Integer page,
            @HttpParam(name = "limit", type = HttpParamType.COMMON, description = "页码长度", valueDef = "20") Integer limit) throws ServiceException;

}
