package com.iotechn.unimall.app.api.market;


import com.iotechn.unimall.core.annotation.HttpMethod;
import com.iotechn.unimall.core.annotation.HttpOpenApi;
import com.iotechn.unimall.core.annotation.HttpParam;
import com.iotechn.unimall.core.annotation.HttpParamType;
import com.iotechn.unimall.core.annotation.param.NotNull;
import com.iotechn.unimall.core.exception.ServiceException;
import com.iotechn.unimall.data.domain.market.MarketOrderDetail;
import com.iotechn.unimall.data.model.Page;

import java.util.Date;

/**
 * 订单详情Service接口
 *
 * @author jlb
 * @date 2022-08-01
 */
@HttpOpenApi(group = "marketOrderDetailApp", description = "订单详情")
public interface IMarketOrderDetailAppService {
    @HttpMethod(description = "新增", permission = "admin:unimall:marketOrderDetail:add", permissionParentName = "宠物管理", permissionName = "订单详情管理")
    public Boolean add(@NotNull @HttpParam(name = "marketOrderDetail", type = HttpParamType.COMMON, description = "订单详情") MarketOrderDetail marketOrderDetail,
                       @HttpParam(name = "adminId", type = HttpParamType.ADMIN_ID, description = "adminId") Long adminId) throws ServiceException;

    @HttpMethod(description = "列表", permission = "admin:unimall:marketOrderDetail:list", permissionParentName = "宠物管理", permissionName = "订单详情管理")
    public Page<MarketOrderDetail> list(
            @HttpParam(name = "companyId", type = HttpParamType.COMMON, description = "") Long companyId,
            @HttpParam(name = "orderId", type = HttpParamType.COMMON, description = "订单id") String orderId,
            @HttpParam(name = "name", type = HttpParamType.COMMON, description = "商品名称") String name,
            @HttpParam(name = "price", type = HttpParamType.COMMON, description = "单价") Double price,
            @HttpParam(name = "num", type = HttpParamType.COMMON, description = "数量") Long num,
            @HttpParam(name = "status", type = HttpParamType.COMMON, description = "状态") String status,
            @HttpParam(name = "deleteFlag", type = HttpParamType.COMMON, description = "0：否（默认） 1：是") Integer deleteFlag,
            @HttpParam(name = "gmtCreate", type = HttpParamType.COMMON, description = "") Date gmtCreate,
            @HttpParam(name = "gmtUpdate", type = HttpParamType.COMMON, description = "") Date gmtUpdate,
            @HttpParam(name = "userId", type = HttpParamType.COMMON, description = "") Long userId,
            @HttpParam(name = "adminId", type = HttpParamType.COMMON, description = "") Long adminId,
            @HttpParam(name = "page", type = HttpParamType.COMMON, description = "页码", valueDef = "1") Integer page,
            @HttpParam(name = "limit", type = HttpParamType.COMMON, description = "页码长度", valueDef = "20") Integer limit)
            throws ServiceException;

    @HttpMethod(description = "删除", permission = "admin:unimall:marketOrderDetail:delete", permissionParentName = "宠物管理", permissionName = "订单详情管理")
    public Boolean delete(@NotNull @HttpParam(name = "id", type = HttpParamType.COMMON, description = "") String id) throws ServiceException;

    @HttpMethod(description = "修改", permission = "admin:unimall:marketOrderDetail:update", permissionParentName = "宠物管理", permissionName = "订单详情管理")
    public Boolean update(@NotNull @HttpParam(name = "marketOrderDetail", type = HttpParamType.COMMON, description = "订单详情") MarketOrderDetail marketOrderDetail,
                          @HttpParam(name = "adminId", type = HttpParamType.ADMIN_ID, description = "adminId") Long adminId) throws ServiceException;

    @HttpMethod(description = "查询", permission = "admin:unimall:marketOrderDetail:get", permissionParentName = "宠物管理", permissionName = "订单详情管理")
    public MarketOrderDetail get(@NotNull @HttpParam(name = "id", type = HttpParamType.COMMON, description = "") Long id) throws ServiceException;

    @HttpMethod(description = "导出excl表", permission = "admin:unimall:marketOrderDetail:export", permissionParentName = "宠物管理", permissionName = "订单详情管理")
    public String export(
            @HttpParam(name = "companyId", type = HttpParamType.COMMON, description = "") Long companyId,
            @HttpParam(name = "orderId", type = HttpParamType.COMMON, description = "订单id") String orderId,
            @HttpParam(name = "name", type = HttpParamType.COMMON, description = "商品名称") String name,
            @HttpParam(name = "price", type = HttpParamType.COMMON, description = "单价") Double price,
            @HttpParam(name = "num", type = HttpParamType.COMMON, description = "数量") Long num,
            @HttpParam(name = "status", type = HttpParamType.COMMON, description = "状态") String status,
            @HttpParam(name = "deleteFlag", type = HttpParamType.COMMON, description = "0：否（默认） 1：是") Integer deleteFlag,
            @HttpParam(name = "gmtCreate", type = HttpParamType.COMMON, description = "") Date gmtCreate,
            @HttpParam(name = "gmtUpdate", type = HttpParamType.COMMON, description = "") Date gmtUpdate,
            @HttpParam(name = "userId", type = HttpParamType.COMMON, description = "") Long userId,
            @HttpParam(name = "adminId", type = HttpParamType.COMMON, description = "") Long adminId,
            @HttpParam(name = "page", type = HttpParamType.COMMON, description = "页码", valueDef = "1") Integer page,
            @HttpParam(name = "limit", type = HttpParamType.COMMON, description = "页码长度", valueDef = "20") Integer limit) throws ServiceException;

}
